@@ -583,15 +583,17 @@ class ControllerRedShift:
                                                 transaction_date,
                                                 transaction_uid,
                                                 user_uid,
-                                                account_uid
+                                                account_uid,
+                                                ammount
                                                 )
-                        VALUES (%s,%s,%s,%s)
+                        VALUES (%s,%s,%s,%s,%s)
                                     '''
             record_to_insert = (
                         dict_values['transaction_date'],
                         dict_values['transaction_uid'],
                         dict_values['user_uid'],
-                        dict_values['account_uid']
+                        dict_values['account_uid'],
+                        dict_values['ammount']
                                 )
             cur.execute(redshift_insert_query, record_to_insert)
             
@@ -604,7 +606,6 @@ class ControllerRedShift:
 
     def creted_table(self,table_name = 'staging'):
         
-
         RedshiftDBTable = sa.Table(
                                 table_name,
                                 self.metadata,
@@ -623,7 +624,6 @@ class ControllerRedShift:
         # Create the table (execute the "CREATE TABLE" SQL statement for "")
         RedshiftDBTable.create(bind=self.engine)
         self.session.commit()
-
         
     def get_date_range(self,num_days = 30):
         # today 
@@ -632,7 +632,6 @@ class ControllerRedShift:
 
         return from_date, to_date
 
-
     def get_collective_is_essential(self):
 
         [from_date, to_date ]= self.get_date_range()
@@ -662,7 +661,6 @@ class ControllerRedShift:
 
         return result.reset_index().drop_duplicates(subset='nickname_recommended', keep='first').set_index('nickname_recommended')['is_essential'].to_dict()
 
-
     def get_collective_is_membership(self):
 
         [from_date, to_date ]= self.get_date_range()
@@ -692,8 +690,6 @@ class ControllerRedShift:
 
         return result.reset_index().drop_duplicates(subset='nickname_recommended', keep='first').set_index('nickname_recommended')['is_membership'].to_dict()
 
-
-
     def get_collective_nickname(self):
 
         [from_date, to_date ]= self.get_date_range()
@@ -724,8 +720,6 @@ class ControllerRedShift:
 
         return result.reset_index().drop_duplicates(subset='clean_description', keep='first').set_index('clean_description')['nickname'].to_dict()
 
-
-
     def get_collective_subcategory(self):
 
         [from_date, to_date ]= self.get_date_range()
