@@ -9,6 +9,12 @@ from klp_commons.controllers.controller_redshift import ControllerRedShift
 from klp_commons.controllers.controller_mongodb import ControllerMongoDB
 from klp_commons.controllers.controller_postgresdb import ControllerPostgresDB
 from klp_commons.datadict.struct_dicts import Transaction_
+
+import logging
+
+logger = logging.getLogger(__name__)
+
+
 null = None
 true = True
 false = False
@@ -201,7 +207,7 @@ front_date = today.strftime("%Y-%m-%d")
 print(today)
 print("front_date: " , front_date)
 
-s = Summary(front_date,num_days = 30)
+s = Summary(front_date,num_days = 240)
 r = s.agg_master()
 
 
@@ -269,6 +275,7 @@ r.replace(np.nan, None, inplace=True)
 r.replace(pd.NaT, None, inplace=True)
 tmp = {'created_at_homologation': pd.NaT}
 
+print(r.columns.tolist())
 
 for idx ,item in enumerate(r.to_dict(orient='records')):
     print(idx, ": ",item['transaction_uid'])
@@ -360,26 +367,31 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     
     user_dict = None
     # new user ?
-    if not MongoDB.exist('user_uid',item['user_uid']):
-        user_dict ={"user_uid":item['user_uid'],
-                    "postcode":None
-                    }
+    #if not MongoDB.exist('user_uid',item['user_uid']):
+    user_dict ={"user_uid":item['user_uid'],
+                "postcode":None
+                }
+    
+    if item['account_uid'] is None:
+        item['account_uid'] = '123'
 
-        # account_dict ={'account_uid': item['account']['account_number'],
-        #                'bank_name':  item['account']['account_institution_name'],
-        #                'account_type': item['account']['account_type'],
-        #                'bank_type': item['account']['account_category']
-        #                }
-        RedShift.insert_dim_user(dict_values = user_dict)
-        # self.RedShift.insert_dim_account(dict_values = account_dict)
-        
-        
-        
-    # print(user_dict)
-    # print("****************************************\n")
-    # print(transaction_dict)
-    
+    account_dict ={
+                    'account_uid': item['account_uid'],
+                    'bank_name':  item['bank_name'],
+                    'account_type': item['account_type'],
+                    'bank_type': item['bank_type']
+                    }
+    RedShift.insert_dim_user(dict_values = user_dict)
+    RedShift.insert_dim_account(dict_values = account_dict)
     
+    print("****************************************\n")
+    print(account_dict)
+    print("****************************************\n")
+    print(user_dict)
+    print("****************************************\n")
+    print(transaction_dict)
+    print("****************************************\n")
+
 
     date_dict = RedShift.date_decomposition(str(item['created_at_head']).replace(" ","T").split(".")[0])
     table_name = 'dim_dates'
@@ -393,14 +405,16 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     fact_transactions_dict['transaction_date'] = str(date_dict['transaction_date'])
     fact_transactions_dict['transaction_uid'] = item['transaction_uid']
     fact_transactions_dict['user_uid'] = item['user_uid']
-    fact_transactions_dict['account_uid'] = ''
+    fact_transactions_dict['account_uid'] = item['account_uid']
+    fact_transactions_dict['ammount'] = 0.0
 
-    #print("----------------------------------------------")
-    #print("\n")
-    # print(transaction_dict)
+ 
+    print("\nfact_transactions_dict: ")
+    print(fact_transactions_dict)
+    print("----------------------------------------------")
 
     # Validación o updated de una transacción 
-    # poner la bandera de Categprización automática
+    # poner la bandera de Categorización automática
     RedShift.insert_dim_transaction(dict_values = transaction_dict)
 
     RedShift.insert_fact_transactions(dict_values = fact_transactions_dict)
